Get MCMC trace draws.
get_draws(foram = NULL, seasonal_seatemp = FALSE)Optional. String or NULL. String indicating the foram
species/subspecies to infer for hierarchical models. String must be one of
"G. bulloides", "G. ruber white", "G. ruber pink", "G. sacculifer",
"N. incompta", or "N. pachyderma sinistral". NULL indicates that a
pooled model is desired.
Optional boolean indicating whether to use the seasonal
sea-surface temperature calibrations. Default is FALSE, i.e. using
annual SST calibrations.
Data frame with columns "alpha", "beta", "tau". Which are equal-length vectors of model parameter draws.
Four calibration models are available: an "annual pooled" model, a
"seasonal pooled" model, an "annual hierarchical" model, and a
"seasonal hierarchical" model. This function uses magic to determine which
"pooled annual" model is used. Which is the simplest case with potential use
for Deep Time reconstructions of nonexant foram species. Giving a valid string
for foram will use a hierarchical model, which has foram-specific
variability in calibration model parameters. Passing TRUE for
seasonal_seatemp will use a model trained on season sea-surface
temperatures. See reference paper for further details.